@@ -1,3 +1,6 @@
+from typing import List, Type
+
+from dmoj.commands.base_command import Command, commands, register_command
 from dmoj.commands.diff import DifferenceCommand
 from dmoj.commands.help import HelpCommand
 from dmoj.commands.problems import ListProblemsCommand
@@ -8,5 +11,14 @@ from dmoj.commands.show import ShowCommand
 from dmoj.commands.submissions import ListSubmissionsCommand
 from dmoj.commands.submit import SubmitCommand
 
-all_commands = [ListProblemsCommand, ListSubmissionsCommand, SubmitCommand, ResubmitCommand, RejudgeCommand,
-                DifferenceCommand, ShowCommand, HelpCommand, QuitCommand]
+all_commands: List[Type[Command]] = [
+    ListProblemsCommand,
+    ListSubmissionsCommand,
+    SubmitCommand,
+    ResubmitCommand,
+    RejudgeCommand,
+    DifferenceCommand,
+    ShowCommand,
+    HelpCommand,
+    QuitCommand,
+]
