@@ -2,14 +2,10 @@
 #ifndef idABBEC9C1_3EF3_4A45_B187B10060CB9F85
 #define idABBEC9C1_3EF3_4A45_B187B10060CB9F85
 
-#define DEBUGGER_X86        0
-#define DEBUGGER_X64        1
-#define DEBUGGER_X86_ON_X64 2
-#define DEBUGGER_X32        3
-#define DEBUGGER_ARM        4
-#define DEBUGGER_ARM64      5
-
-pt_debugger *get_ptdebugger(int type);
+#define PTBOX_SPAWN_FAIL_NO_NEW_PRIVS   202
+#define PTBOX_SPAWN_FAIL_SECCOMP        203
+#define PTBOX_SPAWN_FAIL_TRACEME        204
+#define PTBOX_SPAWN_FAIL_EXECVE         205
 
 struct child_config {
     unsigned long memory;
@@ -25,11 +21,8 @@ struct child_config {
     int stdin_;
     int stdout_;
     int stderr_;
-    int max_fd;
-    int *fds;
-    int debugger_type;
-    int trace_syscalls;
-    int *syscall_whitelist;
+    bool use_seccomp;
+    int *seccomp_whitelist;
 };
 
 void cptbox_closefrom(int lowfd);
@@ -38,4 +31,7 @@ int cptbox_child_run(const struct child_config *config);
 char *bsd_get_proc_cwd(pid_t pid);
 char *bsd_get_proc_fdno(pid_t pid, int fdno);
 
+int memory_fd_create(void);
+int memory_fd_seal(int fd);
+
 #endif
