@@ -1,8 +1,7 @@
-from dmoj.executors.mixins import ScriptDirectoryMixin
 from dmoj.executors.script_executor import ScriptExecutor
 
 
-class Executor(ScriptDirectoryMixin, ScriptExecutor):
+class Executor(ScriptExecutor):
     name = 'FORTH'
     command = 'gforth'
     ext = 'fs'
@@ -13,5 +12,5 @@ HELLO
 '''
     fs = [r'/\.gforth-history$']
 
-    def get_cmdline(self):
+    def get_cmdline(self, **kwargs):
         return [self.get_command(), self._code, '-e', 'bye']
