@@ -11,7 +11,7 @@ class Executor(ScriptExecutor):
     test_program = 'puts gets'
     nproc = -1
     command_paths = ['ruby2.%d' % i for i in reversed(range(0, 8))] + ['ruby2%d' % i for i in reversed(range(0, 8))]
-    syscalls = ['poll', 'thr_set_name', 'eventfd2']
+    syscalls = ['thr_set_name', 'eventfd2']
     fs = ['/proc/self/loginuid$']
 
     def get_fs(self):
