@@ -1,6 +1,4 @@
-import gc
 import logging
-import platform
 import subprocess
 
 from dmoj.error import OutputLimitExceeded
@@ -39,16 +37,6 @@ class StandardGrader(BaseGrader):
 
         case.free_data()
 
-        # Where CPython has reference counting and a GC, PyPy only has a GC. This means that while CPython
-        # will have freed any (usually massive) generated data from the line above by reference counting, it might
-        # - and probably still is - in memory by now. We need to be able to fork() immediately, which has a good chance
-        # of failing if there's not a lot of swap space available.
-        #
-        # We don't really have a way to force the generated data to disappear, so calling a gc here is the best
-        # chance we have.
-        if platform.python_implementation() == 'PyPy':
-            gc.collect()
-
         return result
 
     def populate_result(self, error, result, process):
@@ -105,13 +93,8 @@ class StandardGrader(BaseGrader):
             )
         except OutputLimitExceeded:
             error = b''
-            try:
-                process.kill()
-            except RuntimeError as e:
-                if e.args[0] != 'TerminateProcess: 5':
-                    raise
-            # Otherwise it's a race between this kill and the shocker,
-            # and failed kill means nothing.
+            process.kill()
+        finally:
             process.wait()
         return error
 
