@@ -2,12 +2,14 @@ import logging
 import os
 import sys
 import traceback
+from typing import cast
 
 import yaml
 
 from dmoj import contrib, executors, judgeenv
-from dmoj.judge import Judge
+from dmoj.judge import Judge, Submission
 from dmoj.judgeenv import get_problem_root, get_supported_problems
+from dmoj.packet import PacketManager
 from dmoj.utils.ansi import ansi_style, print_ansi
 
 all_executors = executors.executors
@@ -21,10 +23,12 @@ class TestManager:
         self.output('\t\t' + message.replace('\r\n', '\n').replace('\n', '\r\n\t\t'))
         self.failed = True
 
-    def set_expected(self, codes_all, codes_cases, feedback_all, feedback_cases):
+    def set_expected(self, codes_all, codes_cases, points_all, points_cases, feedback_all, feedback_cases):
         self.failed = False
         self.codes_all = codes_all
         self.codes_cases = codes_cases
+        self.points_all = points_all
+        self.points_cases = points_cases
         self.feedback_all = feedback_all
         self.feedback_cases = feedback_cases
 
@@ -45,6 +49,16 @@ class TestManager:
         elif code not in self.codes_all:
             self.fail('Unexpected global code: %s, expecting %s' % (code, ', '.join(self.codes_all)))
 
+        if position in self.points_cases:
+            if result.points not in self.points_cases[position]:
+                self.fail(
+                    'Unexpected points for case %d: %s, expecting %s'
+                    % (position, result.points, ', '.join(self.points_cases[position]))
+                )
+        elif self.points_all is not None and result.points not in self.points_all:
+            self.fail('Unexpected global points: %s, expecting %s' % (
+                result.points, ', '.join(map(str, self.points_all))))
+
         feedback = self.feedback_all
         if position in self.feedback_cases:
             feedback = self.feedback_cases[position]
@@ -79,26 +93,20 @@ class TestManager:
     def current_submission_packet(self):
         pass
 
-    def submission_terminated_packet(self):
+    def submission_aborted_packet(self):
         pass
 
     def submission_acknowledged_packet(self, sub_id):
         pass
 
 
-class TestJudge(Judge):
-    def __init__(self, manager):
-        super().__init__()
-        self.packet_manager = manager
-
-
 class Tester:
     all_codes = {'AC', 'IE', 'TLE', 'MLE', 'OLE', 'RTE', 'IR', 'WA', 'CE', 'SC'}
 
     def __init__(self, problem_regex=None, case_regex=None):
         self.manager = TestManager()
         self.manager.output = self.error_output
-        self.judge = TestJudge(self.manager)
+        self.judge = Judge(cast(PacketManager, self.manager))
         self.sub_id = 0
         self.problem_regex = problem_regex
         self.case_regex = case_regex
@@ -207,6 +215,9 @@ class Tester:
         codes_all, codes_cases = self.parse_expect(
             config.get('expect', 'AC'), config.get('cases', {}), self.parse_expected_codes
         )
+        points_all, points_cases = self.parse_expect(
+            config.get('points'), config.get('points_cases', {}), self.parse_points
+        )
         feedback_all, feedback_cases = self.parse_expect(
             config.get('feedback'), config.get('feedback_cases', {}), self.parse_feedback
         )
@@ -217,9 +228,11 @@ class Tester:
         fails = 0
         for source in sources:
             self.sub_id += 1
-            self.manager.set_expected(codes_all, codes_cases, feedback_all, feedback_cases)
+            self.manager.set_expected(codes_all, codes_cases, points_all, points_cases, feedback_all, feedback_cases)
             self.judge.begin_grading(
-                self.sub_id, problem, language, source, time, memory, False, {}, blocking=True, report=output_case
+                Submission(self.sub_id, problem, language, source, time, memory, False, {}),
+                blocking=True,
+                report=output_case,
             )
             fails += self.manager.failed
         return fails
@@ -244,6 +257,14 @@ class Tester:
             assert not (result - self.all_codes)
             return result
 
+    def parse_points(self, points):
+        if points is None or points == '*':
+            return None
+        elif isinstance(points, (str, int)):
+            return {int(points)}
+        else:
+            return set(map(int, points))
+
     def parse_feedback(self, feedback):
         if feedback is None or feedback == '*':
             return None
@@ -257,7 +278,7 @@ def main():
     judgeenv.load_env(cli=True, testsuite=True)
 
     logging.basicConfig(
-        filename=judgeenv.log_file, level=logging.INFO, format='%(levelname)s %(asctime)s %(module)s %(message)s'
+        filename=judgeenv.log_file, level=logging.DEBUG, format='%(levelname)s %(asctime)s %(module)s %(message)s'
     )
 
     executors.load_executors()
